@@ -250,7 +250,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r = response.json()
         codes = []
         columns = []
-        for col in response["schema"]:
+        for col in r["schema"]:
             codes.append(col["code"])
             if col["name"] != '':
                 columns.append(col["name"])
@@ -925,7 +925,6 @@ class Askdata(SignUp):
                 "table_right": table_right
             }
         }
-        print(tables)
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
